---
title: PyMergeVCD
author: Kristoffer Nordström
---

![MIT License](https://img.shields.io/github/license/kown7/pymergevcd "MIT License")

# Introduction

Merge VCD files, optionally to create a diff on various files and signals.

Also a playground for [sltoo](https://www.github.com/kown7/sltoo).


# Installation

```bash
pip install pymergevcd
```

## Requirements

Python 3.6+.

## Documentation

Please see the `docs` folder.

## Usage

TBD

